package me.icymint.libra.sage.spring;

import me.icymint.libra.sage.model.SqlFactory;
import me.icymint.libra.sage.model.SqlInfo;

import org.springframework.beans.factory.FactoryBean;
import org.springframework.core.io.Resource;

/**
 * Spring配置Sage SQL工厂的属性。请注意该类用于支持Spring模块。
 * <p>
 * <code>
 * &lt;bean id="xx" class="me.icymint.sage.spring.SqlFactoryBean"&gt; <br>
 * &lt;property name="sqlInfo"&gt;<br>
 * &lt;bean class="me.icymint.sage.model.SqlInfo"&gt;<br>
 * &lt;constructor-arg value="true" /&gt;<br>
 * &lt;constructor-arg&gt;<br>
 * &lt;bean class="me.icymint.sage.core.JdbcUtils"&gt;<br>
 * &lt;constructor-arg ref="dataSource" /&gt;<br>
 * &lt;constructor-arg value="atest" /&gt;<br>
 * &lt;/bean&gt;<br>
 * &lt;/constructor-arg&gt;<br>
 * &lt;/bean&gt;<br>
 * &lt;/property&gt;<br>
 * &lt;property name="xml"&gt;<br>
 * &lt;bean class="org.springframework.core.io.ClassPathResource"&gt;<br>
 * &lt;constructor-arg value="me/icymint/sage/1.xml" /&gt;<br>
 * &lt;/bean&gt;<br>
 * &lt;/property&gt;<br>
 * &lt;/bean&gt;
 * </code>
 * 
 * @author Daniel
 * @datetime 2013-1-23下午3:54:37
 * 
 * 
 */
public class SqlFactoryBean implements FactoryBean<SqlFactory> {
	private SqlInfo si;
	private Resource xml;

	@Override
	public SqlFactory getObject() throws Exception {
		return SqlFactory.newInstance(si, xml.getInputStream());
	}

	@Override
	public Class<?> getObjectType() {
		return SqlFactory.class;
	}

	public SqlInfo getSqlInfo() {
		return si;
	}

	@Override
	public boolean isSingleton() {
		return true;
	}

	public void setSqlInfo(SqlInfo si) {
		this.si = si;
	}

	public void setXml(Resource xml) {
		this.xml = xml;
	}

}
